@@ -51,7 +51,6 @@
 #include "gsm-sound.h"
 #include "gsm-gsd.h"
 #include "gsm-keyring.h"
-#include "gsm-xrandr.h"
 #include "gsm-at-startup.h"
 #include "gsm-remote-desktop.h"
 
@@ -614,7 +613,8 @@ main (int argc, char *argv[])
   GConfClient *gconf_client;
   GOptionContext *goption_context;
   gboolean dbus_daemon_owner;
-  
+  GnomeProgram *program;
+
   if (g_getenv ("GSM_VERBOSE_DEBUG"))
     gsm_set_verbose (TRUE);
 
@@ -651,9 +651,6 @@ main (int argc, char *argv[])
   if (gsm_check_for_root ())
     return 0;
 
-  /* We need to do this as early as possible */
-  gsm_set_display_properties ();
-  
   if (ORBit_proto_use ("IPv4") || ORBit_proto_use ("IPv6"))
     gnome_login_check ();
 
@@ -697,9 +694,10 @@ main (int argc, char *argv[])
   g_option_context_set_translation_domain (goption_context, GETTEXT_PACKAGE);
   g_option_context_add_main_entries (goption_context, options, GETTEXT_PACKAGE);
 
-  gnome_program_init("gnome-session", VERSION, LIBGNOMEUI_MODULE, argc, argv, 
-		  GNOME_PARAM_GOPTION_CONTEXT, goption_context,
-		  NULL);
+  program = gnome_program_init ("gnome-session", VERSION, LIBGNOMEUI_MODULE,
+                                argc, argv,
+                                GNOME_PARAM_GOPTION_CONTEXT, goption_context,
+                                NULL);
 
  /* FIXME: it would be nice to skip this check if we're debugging the
  session manager. */
@@ -805,5 +803,7 @@ main (int argc, char *argv[])
 
   g_free (session_name);
 
+  g_object_unref (program);
+
   return 0;
 }
